@@ -1,7 +1,7 @@
 #!/bin/bash
-VERSION='0.6'
+VERSION='0.7'
 #
-# Copyright (C) 2003-2010  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2003-2010  Ola Lundqvist <ola@inguza.com>
 # Copyright (C) 2009       Stefan Tomanek <stefan@pico.ruhr.de>
 # Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 # Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
@@ -62,8 +62,9 @@ REMOVE_PACKAGES="lilo,makedev,nfs-kernel-server,lpr"
 ARCH=""
 
 # Which debian distribution
-# (warning: this has only been tested with woody, sarge, etch and lenny)
-DIST="lenny"
+# (warning: this has only been tested with
+#  woody, sarge, etch, lenny and squeeze)
+DIST="squeeze"
 
 # Local or nearest location of a debian mirror (must include the `/debian')
 MIRROR="http://ftp.uk.debian.org/debian"
@@ -121,7 +122,7 @@ Options:
         -V, --version		copyright and version information
 	--arch			set target architecture (eg. --arch "i386")
 				(autodetected on Debian host if dpkg available)
-	--dist			defaults to "lenny", passed to debootstrap.
+	--dist			defaults to "squeeze", passed to debootstrap.
 	--context n             Set the context id to be used.
 	--fakeinit		use "/sbin/init" to boot vserver
 	--conffile		extra configuration file to load.
@@ -149,7 +150,7 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (C) 2003-2008  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2003-2010  Ola Lundqvist <ola@inguza.com>
 Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
 Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
@@ -212,13 +213,13 @@ parse_args ()
 			case "$2" in
 			    [a-z]*)
 				DIST="$2"
-				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] && [ "lenny" != "$2" ] ; then
-				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\", \"etch\" and \"lenny\", be careful!" 1>&2
+				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] && [ "lenny" != "$2" ] && [ "squeeze" != "$2" ] ; then
+				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\", \"etch\", \"lenny\" and \"squeeze\", be careful!" 1>&2
 				fi
 				;;
 			    *)
 				echo "${0##*/} error: $1 requires a Debian distribution" 1>&2
-				echo 'e.g. "woody", "sarge", "etch" or "lenny"' 1>&2
+				echo 'e.g. "woody", "sarge", "etch", "lenny" and "squeeze"' 1>&2
 				exit 1
 				;;
 			esac
