@@ -1,7 +1,7 @@
 #!/bin/bash
-VERSION='0.6'
+VERSION='0.7'
 #
-# Copyright (C) 2002-2010  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2010  Ola Lundqvist <ola@inguza.com>
 # Copyright (C) 2009       Stefan Tomanek <stefan@pico.ruhr.de>
 # Copyright (C) 2008       Vincent Bernat <bernat@luffy.cx>
 # Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
@@ -72,8 +72,9 @@ POST_INSTALL_HOST_SCRIPT=""
 ARCH=""
 
 # Which debian distribution
-# (warning: this has only been tested with woody, sarge, etch and lenny)
-DIST="lenny"
+# (warning: this has only been tested with
+#  woody, sarge, etch, lenny and squeeze)
+DIST="squeeze"
 
 # Local or nearest location of a debian mirror (must include the `/debian')
 MIRROR="http://ftp.uk.debian.org/debian"
@@ -125,7 +126,7 @@ Options:
         -V, --version		copyright and version information
 	--arch			set target architecture (eg. --arch "i386")
 				(autodetected on Debian host if dpkg available)
-	--dist			defaults to "lenny", passed to debootstrap.
+	--dist			defaults to "squeeze", passed to debootstrap.
 	--context n             Set the context id to be used.
 	--fakeinit		use "/sbin/init" to boot vserver
 	--conffile		extra configuration file to load.
@@ -154,7 +155,7 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2002-2010  Ola Lundqvist <ola@inguza.com>
 Copyright (C) 2008       Vincent Bernat <bernat@luffy.cx>
 Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
@@ -236,13 +237,13 @@ parse_args ()
 			case "$2" in
 			    [a-z]*)
 				DIST="$2"
-				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] && [ "lenny" != "$2" ] ; then
-				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\", \"etch\" and \"lenny\", be careful!" 1>&2
+				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] && [ "lenny" != "$2" ] && [ "squeeze" != "$2" ] ; then
+				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\", \"etch\", \"lenny\" and \"squeeze\", be careful!" 1>&2
 				fi
 				;;
 			    *)
 				echo "${0##*/} error: $1 requires a Debian distribution" 1>&2
-				echo 'e.g. "woody", "sarge", "etch" or "lenny"' 1>&2
+				echo 'e.g. "woody", "sarge", "etch", "lenny" or "squeeze"' 1>&2
 				exit 1
 				;;
 			esac
@@ -534,10 +535,18 @@ fi
 
 # Fix up the available device nodes (mostly done by vserver-build above)
 if cd "$VROOTDIR/$VHOST/dev"; then
-    ln -s /proc/self/fd fd
-    ln -s fd/2 stderr
-    ln -s fd/0 stdin
-    ln -s fd/1 stdout
+    if [ ! -L fd ] && [ ! -e fd ] ; then
+	ln -s /proc/self/fd fd
+    fi
+    if [ ! -L stderr ] && [ ! -e stderr ] ; then
+	ln -s fd/2 stderr
+    fi
+    if [ ! -L stdin ] && [ ! -e stdin ] ; then
+	ln -s fd/0 stdin
+    fi
+    if [ ! -L stdout ] && [ ! -e stdout ] ; then
+	ln -s fd/1 stdout
+    fi
 fi
 
 # Give the new host a hostname
@@ -585,9 +594,11 @@ proc		/proc		proc	defaults			0	0
 EOF
 
 # Create a reduced inittab that doesn't start getty on the consoles
-mv "$VROOTDIR/$VHOST/etc/inittab" "$VROOTDIR/$VHOST/etc/inittab.dist" && \
-    grep -v respawn\:/sbin/getty "$VROOTDIR/$VHOST/etc/inittab.dist" > \
-    "$VROOTDIR/$VHOST/etc/inittab" && rm -f "$VROOTDIR/$VHOST/etc/inittab.dist"
+if [ -e "$VROOTDIR/$VHOST/etc/inittab" ] ; then
+    mv "$VROOTDIR/$VHOST/etc/inittab" "$VROOTDIR/$VHOST/etc/inittab.dist" && \
+	grep -v respawn\:/sbin/getty "$VROOTDIR/$VHOST/etc/inittab.dist" > \
+	"$VROOTDIR/$VHOST/etc/inittab" && rm -f "$VROOTDIR/$VHOST/etc/inittab.dist"
+fi
 
 # By default the Debian Install script runs zillions of cron jobs at
 # 0625 every morning.  On a system with lots of vservers all trying to
