@@ -1,7 +1,7 @@
 #!/bin/bash
-VERSION='0.6'
+VERSION='0.7'
 #
-# Copyright (C) 2002-2010  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2010  Ola Lundqvist <ola@inguza.com>
 # Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 # Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 # Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
@@ -98,7 +98,7 @@ Options:
 				(autodetected on Debian host if dpkg available)
 	--copy-vreboot		install "vreboot/vshutdown/vhalt"
 	--no-copy-vreboot	don't install "vreboot/vshutdown/vhalt"
-	--dist			Depricated option.
+	--dist			Deprecated option.
 	--fakeinit		use "/sbin/init" to boot vserver
 	--conffile		extra configuration file to load.
 	--interface		interface for IP addresses (if not "eth0")
@@ -117,7 +117,7 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2002-2010  Ola Lundqvist <ola@inguza.com>
 Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
